@@ -5,9 +5,9 @@ import json
 import string
 import os
 
-from cvapianalyser import CVApiAnalyser
-from cvapianalyser import CommunityEdition
-from openapispecdiff import OpenApiSpecDiff
+from cvapianalyser.CVApiAnalyser import CVApiAnalyser
+from cvapianalyser.CommunityEdition import CommunityEdition
+from openapispecdiff.OpenApiSpecDiff import OpenApiSpecDiff
 
 class CVTrafficRegenerator(object):
     def __init__(self, APISpecOne, APISpecTwo, ce_host, ce_username, ce_password):
